# ti-ding
Python package to notify when a process is finished in the terminal.


## pip installation
Installation: ``` pip install ti-ding ```  
Usage: ``` notify <command> ```

## download repo
Build: ```python -m build```
       ```pip install .```         
Usage: ``` notify <command> ```

## Next goals 
Add support for mac and unix commands  
Add option to use different audio files
